==> ewd-document-store-1.23.0.tgz: package/lib/proto/convert.js <==
/*

 ----------------------------------------------------------------------------
 | ewd-document-store: Persistent JavaScript Objects and Document Database  |
 |                      using Global Storage                                |
 |                                                                          |
 | Copyright (c) 2016-18 M/Gateway Developments Ltd,                        |
 | Redhill, Surrey UK.                                                      |
 | All rights reserved.                                                     |
 |                                                                          |
 | http://www.mgateway.com                                                  |
 | Email: rtweed@mgateway.com                                               |
 |                                                                          |
 |                                                                          |
 | Licensed under the Apache License, Version 2.0 (the "License");          |
 | you may not use this file except in compliance with the License.         |
 | You may obtain a copy of the License at                                  |
 |                                                                          |
 |     http://www.apache.org/licenses/LICENSE-2.0                           |
 |                                                                          |
 | Unless required by applicable law or agreed to in writing, software      |
 | distributed under the License is distributed on an "AS IS" BASIS,        |
 | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
 | See the License for the specific language governing permissions and      |
 |  limitations under the License.                                          |
 ----------------------------------------------------------------------------

  9 April 2018

*/

module.exports = function(value){
  // data fetched is always a string.  Convert to appropriate JS type if possible
  if (typeof value === 'undefined') return '';
  if (value === 'true') return true;
  if (value === 'false') return false;
  if (value.length > 1 && value[0] === '0') {
    if (value.length > 2 && value[1] === '.') return Number(value);
    return value;
  }
  if (!isNaN(value) && !isNaN(parseFloat(value))) return Number(value);
  return value;
};

==> ewd-document-store-1.24.0.tgz: package/lib/proto/convert.js <==
/*

 ----------------------------------------------------------------------------
 | ewd-document-store: Persistent JavaScript Objects and Document Database  |
 |                      using Global Storage                                |
 |                                                                          |
 | Copyright (c) 2016-18 M/Gateway Developments Ltd,                        |
 | Redhill, Surrey UK.                                                      |
 | All rights reserved.                                                     |
 |                                                                          |
 | http://www.mgateway.com                                                  |
 | Email: rtweed@mgateway.com                                               |
 |                                                                          |
 |                                                                          |
 | Licensed under the Apache License, Version 2.0 (the "License");          |
 | you may not use this file except in compliance with the License.         |
 | You may obtain a copy of the License at                                  |
 |                                                                          |
 |     http://www.apache.org/licenses/LICENSE-2.0                           |
 |                                                                          |
 | Unless required by applicable law or agreed to in writing, software      |
 | distributed under the License is distributed on an "AS IS" BASIS,        |
 | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
 | See the License for the specific language governing permissions and      |
 |  limitations under the License.                                          |
 ----------------------------------------------------------------------------

  29 May 2018

*/

module.exports = function(value){
  // data fetched is always a string.  Convert to appropriate JS type if possible
  if (typeof value === 'undefined') return '';
  if (value === 'true') return true;
  if (value === 'false') return false;
  /*
  if (value.length > 1 && value[0] === '0') {
    if (value.length > 2 && value[1] === '.') {
      var num = Number(value);
      if (!isNaN(num)) return num;
      return value;
    }
  }
  */
  if (!isNaN(value) && !isNaN(parseFloat(value))) return Number(value);
  return value;
};
